#ifndef __vtkICPFilter_h
#define __vtkICPFilter_h

#include "vtkSmartPointer.h" // compiler errors if this is forward declared

#include "vtkPolyDataAlgorithm.h" //superclass
#include "vtkExecutive.h"

class vtkPolyData;
class vtkTransform;
class vtkInformation;
class vtkInformationVector;
class vtkIterativeClosestPointTransform;

#include "vtkMath.h"

class vtkICPFilter : public vtkPolyDataAlgorithm
{
 public:
  static vtkICPFilter *New();
  vtkTypeRevisionMacro(vtkICPFilter, vtkPolyDataAlgorithm);
  void PrintSelf(ostream &os, vtkIndent indent);

  // Description:
  // Specify the source object. This is the object that will be moved during the transformation.
  vtkPolyData *GetSource();

  // Description:
  // Specify the target object. This is the object that will stay in place.
  vtkPolyData *GetTarget();

  void AddSourceConnection(vtkAlgorithmOutput* input);
  void RemoveAllSources();

	//void SetStartByMatchingCentroids(const int start) {this->bStartByMatchingCentroids = start;}
vtkSetMacro(bStartByMatchingCentroids, int);
vtkSetMacro(bRigidBody, int);

 protected:
  vtkICPFilter();
  ~vtkICPFilter();

  // Make sure the pipeline knows what type we expect as input
  int FillInputPortInformation( int port, vtkInformation* info );

  // Generate output
  int RequestData(vtkInformation *, vtkInformationVector **, vtkInformationVector *); //the function that makes this class work with the vtk pipeline

 private:
  //BTX
  // BTX-ETX comment is to hide these variable declarations from
  // bin/vtkWrapClientServer. If omitted, we'd get a
  // *** SYNTAX ERROR found in parsing the header file vtkICPFilter.h before line 34 ***

  vtkSmartPointer<vtkIterativeClosestPointTransform> ICPTransform;
  //ETX

	int bStartByMatchingCentroids;
	int bRigidBody;
};
#endif

